Debug

Trait Debug 

1.6.0 ยท Source
pub trait Debug: PointeeSized {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result;
}
? formatting.

Debug should format the output in a programmer-facing, debugging context.

Generally speaking, you should just derive a Debug implementation.

When used with the alternate format specifier #?, the output is pretty-printed.

For more information on formatters, see the module-level documentation.

This trait can be used with #[derive] if all fields implement Debug. When derived for structs, it will use the name of the struct, then {, then a comma-separated list of each fieldโ€™s name and Debug value, then }. For enums, it will use the name of the variant and, if applicable, (, then the Debug values of the fields, then ).

Stability

Derived Debug formats are not stable, and so may change with future Rust versions. Additionally, Debug implementations of types provided by the standard library (std, core, alloc, etc.) are not stable, and may also change with future Rust versions.

Examples

Deriving an implementation:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

Manually implementing:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_struct("Point")
         .field("x", &self.x)
         .field("y", &self.y)
         .finish()
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(
    format!("The origin is: {origin:?}"),
    "The origin is: Point { x: 0, y: 0 }",
);

There are a number of helper methods on the Formatter struct to help you with manual implementations, such as debug_struct.

Types that do not wish to use the standard suite of debug representations provided by the Formatter trait (debug_struct, debug_tuple, debug_list, debug_set, debug_map) can do something totally custom by manually writing an arbitrary representation to the Formatter.

impl fmt::Debug for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "Point [{} {}]", self.x, self.y)
    }
}

Debug implementations using either derive or the debug builder API on Formatter support pretty-printing using the alternate flag: {:#?}.

Pretty-printing with #?:

#[derive(Debug)]
struct Point {
    x: i32,
    y: i32,
}

let origin = Point { x: 0, y: 0 };

let expected = "The origin is: Point {
    x: 0,
    y: 0,
}";
assert_eq!(format!("The origin is: {origin:#?}"), expected);

Required Methods

1.0.0 ยท Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Debug for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_tuple("")
         .field(&self.longitude)
         .field(&self.latitude)
         .finish()
    }
}

let position = Position { longitude: 1.987, latitude: 2.983 };
assert_eq!(format!("{position:?}"), "(1.987, 2.983)");

assert_eq!(format!("{position:#?}"), "(
    1.987,
    2.983,
)");

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Debug for !

1.0.0 ยท Source

impl Debug for ()

Source

impl Debug for Abi

1.0.0 ยท Source

impl Debug for AddrParseError

Source

impl Debug for core::mem::Alignment

1.28.0 ยท Source

impl Debug for core::fmt::Alignment

Source

impl Debug for AllocError

1.0.0 ยท Source

impl Debug for Arguments<'_>

Source

impl Debug for Array

Source

impl Debug for AsciiChar

Source

impl Debug for Assume

1.3.0 ยท Source

impl Debug for AtomicBool

1.34.0 ยท Source

impl Debug for AtomicI8

1.34.0 ยท Source

impl Debug for AtomicI16

1.34.0 ยท Source

impl Debug for AtomicI32

1.34.0 ยท Source

impl Debug for AtomicI64

1.3.0 ยท Source

impl Debug for AtomicIsize

Source

impl Debug for AtomicOrdering

1.34.0 ยท Source

impl Debug for AtomicU8

1.34.0 ยท Source

impl Debug for AtomicU16

1.34.0 ยท Source

impl Debug for AtomicU32

1.34.0 ยท Source

impl Debug for AtomicU64

1.3.0 ยท Source

impl Debug for AtomicUsize

Source

impl Debug for Bool

1.13.0 ยท Source

impl Debug for BorrowError

1.13.0 ยท Source

impl Debug for BorrowMutError

Source

impl Debug for ByteStr

1.3.0 ยท Source

impl Debug for CStr

Shows the underlying bytes as a normal string, with invalid UTF-8 presented as hex escape sequences.

Source

impl Debug for Char

Source

impl Debug for CharCase

1.34.0 ยท Source

impl Debug for CharTryFromError

1.38.0 ยท Source

impl Debug for Chars<'_>

Source

impl Debug for Const

1.36.0 ยท Source

impl Debug for Context<'_>

1.27.0 ยท Source

impl Debug for CpuidResult

Available on x86 or x86-64 only.
Source

impl Debug for DebugAsHex

1.9.0 ยท Source

impl Debug for DecodeUtf16Error

1.27.0 ยท Source

impl Debug for Duration

Source

impl Debug for DynTrait

Source

impl Debug for DynTraitPredicate

1.0.0 ยท Source

impl Debug for core::io::Empty

1.17.0 ยท Source

impl Debug for EncodeUtf16<'_>

Source

impl Debug for Enum

1.0.0 ยท Source

impl Debug for core::io::Error

1.0.0 ยท Source

impl Debug for core::fmt::Error

1.0.0 ยท Source

impl Debug for ErrorKind

1.20.0 ยท Source

impl Debug for core::char::EscapeDebug

1.16.0 ยท Source

impl Debug for core::ascii::EscapeDefault

1.0.0 ยท Source

impl Debug for core::char::EscapeDefault

1.0.0 ยท Source

impl Debug for core::char::EscapeUnicode

Source

impl Debug for Field

Source

impl Debug for FieldId

Source

impl Debug for Float

Source

impl Debug for FnPtr

Source

impl Debug for FormattingOptions

1.0.0 ยท Source

impl Debug for FpCategory

1.69.0 ยท Source

impl Debug for FromBytesUntilNulError

1.64.0 ยท Source

impl Debug for FromBytesWithNulError

Source

impl Debug for Generic

Source

impl Debug for GenericType

1.86.0 ยท Source

impl Debug for GetDisjointMutError

Source

impl Debug for core::arch::hexagon::v64::HvxVector

Available on Hexagon only.
Source

impl Debug for core::arch::hexagon::v128::HvxVector

Available on Hexagon only.
Source

impl Debug for core::arch::hexagon::v64::HvxVectorPair

Available on Hexagon only.
Source

impl Debug for core::arch::hexagon::v128::HvxVectorPair

Available on Hexagon only.
Source

impl Debug for core::arch::hexagon::v64::HvxVectorPred

Available on Hexagon only.
Source

impl Debug for core::arch::hexagon::v128::HvxVectorPred

Available on Hexagon only.
1.34.0 ยท Source

impl Debug for Infallible

Source

impl Debug for Int

1.55.0 ยท Source

impl Debug for IntErrorKind

1.7.0 ยท Source

impl Debug for IpAddr

1.0.0 ยท Source

impl Debug for Ipv4Addr

1.0.0 ยท Source

impl Debug for Ipv6Addr

Source

impl Debug for Ipv6MulticastScope

Source

impl Debug for Last

1.28.0 ยท Source

impl Debug for Layout

1.50.0 ยท Source

impl Debug for LayoutError

Source

impl Debug for Lifetime

Source

impl Debug for LocalWaker

Source

impl Debug for Locality

1.10.0 ยท Source

impl Debug for Location<'_>

1.0.0 ยท Source

impl Debug for core::cmp::Ordering

1.0.0 ยท Source

impl Debug for core::sync::atomic::Ordering

1.81.0 ยท Source

impl Debug for PanicMessage<'_>

1.0.0 ยท Source

impl Debug for ParseBoolError

1.20.0 ยท Source

impl Debug for ParseCharError

1.0.0 ยท Source

impl Debug for ParseFloatError

1.0.0 ยท Source

impl Debug for ParseIntError

Source

impl Debug for PhantomContravariantLifetime<'_>

Source

impl Debug for PhantomCovariantLifetime<'_>

Source

impl Debug for PhantomInvariantLifetime<'_>

1.33.0 ยท Source

impl Debug for PhantomPinned

Source

impl Debug for Pointer

1.0.0 ยท Source

impl Debug for RangeFull

1.36.0 ยท Source

impl Debug for RawWaker

1.36.0 ยท Source

impl Debug for RawWakerVTable

Source

impl Debug for Reference

1.16.0 ยท Source

impl Debug for core::io::Repeat

Source

impl Debug for SearchStep

Source

impl Debug for Sign

Source

impl Debug for SimdAlign

1.0.0 ยท Source

impl Debug for Sink

1.0.0 ยท Source

impl Debug for SipHasher

Source

impl Debug for Slice

1.0.0 ยท Source

impl Debug for SocketAddr

1.0.0 ยท Source

impl Debug for SocketAddrV4

1.0.0 ยท Source

impl Debug for SocketAddrV6

Source

impl Debug for Str

Source

impl Debug for Struct

Source

impl Debug for ToCasefold

1.0.0 ยท Source

impl Debug for ToLowercase

Source

impl Debug for ToTitlecase

1.0.0 ยท Source

impl Debug for ToUppercase

Source

impl Debug for Trait

1.59.0 ยท Source

impl Debug for TryFromCharError

1.66.0 ยท Source

impl Debug for TryFromFloatSecsError

1.34.0 ยท Source

impl Debug for TryFromIntError

1.34.0 ยท Source

impl Debug for TryFromSliceError

Source

impl Debug for Tuple

Source

impl Debug for Type

1.0.0 ยท Source

impl Debug for TypeId

Source

impl Debug for TypeKind

Source

impl Debug for Union

1.79.0 ยท Source

impl Debug for Utf8Chunks<'_>

1.0.0 ยท Source

impl Debug for Utf8Error

Source

impl Debug for VaList<'_>

Source

impl Debug for Variant

1.36.0 ยท Source

impl Debug for Waker

1.27.0 ยท Source

impl Debug for __m128

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Debug for __m256

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Debug for __m512

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Debug for __m128bh

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Debug for __m128d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Debug for __m128h

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Debug for __m128i

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Debug for __m256bh

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Debug for __m256d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Debug for __m256h

Available on x86 or x86-64 only.
1.27.0 ยท Source

impl Debug for __m256i

Available on x86 or x86-64 only.
1.89.0 ยท Source

impl Debug for __m512bh

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Debug for __m512d

Available on x86 or x86-64 only.
1.94.0 ยท Source

impl Debug for __m512h

Available on x86 or x86-64 only.
1.72.0 ยท Source

impl Debug for __m512i

Available on x86 or x86-64 only.
Source

impl Debug for __tile1024i

Available on x86-64 only.
Source

impl Debug for bf16

Available on x86 or x86-64 only.
1.0.0 ยท Source

impl Debug for bool

1.16.0 ยท Source

impl Debug for c_void

1.0.0 ยท Source

impl Debug for char

1.0.0 ยท Source

impl Debug for dyn Any

1.0.0 ยท Source

impl Debug for dyn Any + Send

1.28.0 ยท Source

impl Debug for dyn Any + Send + Sync

1.0.0 ยท Source

impl Debug for f16

1.0.0 ยท Source

impl Debug for f32

1.0.0 ยท Source

impl Debug for f64

Source

impl Debug for f16x2

Available on NVidia GPU only.
1.0.0 ยท Source

impl Debug for f128

1.94.0 ยท Source

impl Debug for float16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.94.0 ยท Source

impl Debug for float16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for float64x1_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x1x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x1x3_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x1x4_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x2x2_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x2x3_t

Available on AArch64 or ARM64EC only.
1.59.0 ยท Source

impl Debug for float64x2x4_t

Available on AArch64 or ARM64EC only.
1.0.0 ยท Source

impl Debug for i8

1.0.0 ยท Source

impl Debug for i16

1.0.0 ยท Source

impl Debug for i32

1.0.0 ยท Source

impl Debug for i64

1.0.0 ยท Source

impl Debug for i128

1.59.0 ยท Source

impl Debug for int8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for int64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.0.0 ยท Source

impl Debug for isize

Source

impl Debug for m128

Available on LoongArch64 only.
Source

impl Debug for m256

Available on LoongArch64 only.
Source

impl Debug for m128d

Available on LoongArch64 only.
Source

impl Debug for m128i

Available on LoongArch64 only.
Source

impl Debug for m256d

Available on LoongArch64 only.
Source

impl Debug for m256i

Available on LoongArch64 only.
Source

impl Debug for objc_class

Available on Apple only.
Source

impl Debug for objc_selector

Available on Apple only.
1.59.0 ยท Source

impl Debug for poly8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for poly64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.0.0 ยท Source

impl Debug for str

Source

impl Debug for svbool_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat32_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat64_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svfloat64x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint8_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint8x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint8x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint8x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint16_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint16x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint16x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint16x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint32_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint64_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svint64x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svpattern

Available on AArch64 or ARM64EC only.
Source

impl Debug for svprfop

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint8_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint8x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint8x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint8x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint16_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint16x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint16x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint16x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint32_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint32x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint32x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint32x4_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint64_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint64x2_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint64x3_t

Available on AArch64 or ARM64EC only.
Source

impl Debug for svuint64x4_t

Available on AArch64 or ARM64EC only.
1.0.0 ยท Source

impl Debug for u8

1.0.0 ยท Source

impl Debug for u16

1.0.0 ยท Source

impl Debug for u32

1.0.0 ยท Source

impl Debug for u64

1.0.0 ยท Source

impl Debug for u128

1.59.0 ยท Source

impl Debug for uint8x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x16_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x16x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x16x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint8x16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x8_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x8x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x8x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint16x8x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x4x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x4x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint32x4x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x1_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x1x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x1x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x1x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x2x2_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x2x3_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.59.0 ยท Source

impl Debug for uint64x2x4_t

Available on (AArch64 or ARM or ARM64EC) and (AArch64 or ARM64EC or target feature v7) only.
1.0.0 ยท Source

impl Debug for usize

1.54.0 ยท Source

impl Debug for v128

Available on target_family=wasm only.
Source

impl Debug for core::arch::powerpc::vector_bool_char

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_bool_char

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_bool_int

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_bool_int

Available on s390x only.
Source

impl Debug for vector_bool_long

Available on PowerPC or PowerPC64 only.
Source

impl Debug for vector_bool_long_long

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_bool_short

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_bool_short

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_double

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_double

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_float

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_float

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_signed_char

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_signed_char

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_signed_int

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_signed_int

Available on s390x only.
Source

impl Debug for vector_signed_long

Available on PowerPC or PowerPC64 only.
Source

impl Debug for vector_signed_long_long

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_signed_short

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_signed_short

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_unsigned_char

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_unsigned_char

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_unsigned_int

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_unsigned_int

Available on s390x only.
Source

impl Debug for vector_unsigned_long

Available on PowerPC or PowerPC64 only.
Source

impl Debug for vector_unsigned_long_long

Available on s390x only.
Source

impl Debug for core::arch::powerpc::vector_unsigned_short

Available on PowerPC or PowerPC64 only.
Source

impl Debug for core::arch::s390x::vector_unsigned_short

Available on s390x only.
Source

impl<'a, 'b, const N: usize> Debug for CharArrayRefSearcher<'a, 'b, N>

Source

impl<'a, 'b> Debug for CharSliceSearcher<'a, 'b>

Source

impl<'a, 'b> Debug for StrSearcher<'a, 'b>

1.0.0 ยท Source

impl<'a, A: Debug + 'a> Debug for core::option::Iter<'a, A>

1.0.0 ยท Source

impl<'a, A: Debug + 'a> Debug for core::option::IterMut<'a, A>

Source

impl<'a, I: Debug> Debug for ByRefSized<'a, I>

1.51.0 ยท Source

impl<'a, P: Pattern<Searcher<'a>: Debug>> Debug for core::str::SplitInclusive<'a, P>

1.5.0 ยท Source

impl<'a, P> Debug for MatchIndices<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.2.0 ยท Source

impl<'a, P> Debug for Matches<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.5.0 ยท Source

impl<'a, P> Debug for RMatchIndices<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.2.0 ยท Source

impl<'a, P> Debug for RMatches<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for core::str::RSplit<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for core::str::RSplitN<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for RSplitTerminator<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for core::str::Split<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for core::str::SplitN<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.0.0 ยท Source

impl<'a, P> Debug for SplitTerminator<'a, P>
where P: Pattern<Searcher<'a>: Debug>,

1.77.0 ยท Source

impl<'a, T: 'a + Debug, P> Debug for ChunkBy<'a, T, P>

1.77.0 ยท Source

impl<'a, T: 'a + Debug, P> Debug for ChunkByMut<'a, T, P>

1.94.0 ยท Source

impl<'a, T: Debug + 'a, const N: usize> Debug for ArrayWindows<'a, T, N>

1.0.0 ยท Source

impl<'a, T: Debug + 'a> Debug for Chunks<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for ChunksExact<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for ChunksExactMut<'a, T>

1.0.0 ยท Source

impl<'a, T: Debug + 'a> Debug for ChunksMut<'a, T>

1.0.0 ยท Source

impl<'a, T: Debug + 'a> Debug for core::result::Iter<'a, T>

1.0.0 ยท Source

impl<'a, T: Debug + 'a> Debug for core::result::IterMut<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for RChunks<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for RChunksExact<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for RChunksExactMut<'a, T>

1.31.0 ยท Source

impl<'a, T: Debug + 'a> Debug for RChunksMut<'a, T>

1.0.0 ยท Source

impl<'a, T: Debug + 'a> Debug for Windows<'a, T>

Source

impl<'a, const N: usize> Debug for CharArraySearcher<'a, N>

Source

impl<'a> Debug for core::ffi::c_str::Bytes<'a>

1.0.0 ยท Source

impl<'a> Debug for core::str::Bytes<'a>

1.0.0 ยท Source

impl<'a> Debug for CharIndices<'a>

Source

impl<'a> Debug for CharSearcher<'a>

Source

impl<'a> Debug for ContextBuilder<'a>

1.60.0 ยท Source

impl<'a> Debug for EscapeAscii<'a>

1.34.0 ยท Source

impl<'a> Debug for core::str::EscapeDebug<'a>

1.34.0 ยท Source

impl<'a> Debug for core::str::EscapeDefault<'a>

1.34.0 ยท Source

impl<'a> Debug for core::str::EscapeUnicode<'a>

1.36.0 ยท Source

impl<'a> Debug for IoSlice<'a>

1.36.0 ยท Source

impl<'a> Debug for IoSliceMut<'a>

1.0.0 ยท Source

impl<'a> Debug for Lines<'a>

1.0.0 ยท Source

impl<'a> Debug for LinesAny<'a>

1.10.0 ยท Source

impl<'a> Debug for PanicInfo<'a>

Source

impl<'a> Debug for Request<'a>

Source

impl<'a> Debug for Source<'a>

1.34.0 ยท Source

impl<'a> Debug for SplitAsciiWhitespace<'a>

1.1.0 ยท Source

impl<'a> Debug for SplitWhitespace<'a>

1.79.0 ยท Source

impl<'a> Debug for Utf8Chunk<'a>

Source

impl<'a> Debug for Utf8Pattern<'a>

1.0.0 ยท Source

impl<A: Debug, B: Debug> Debug for core::iter::Chain<A, B>

1.0.0 ยท Source

impl<A: Debug, B: Debug> Debug for Zip<A, B>

1.0.0 ยท Source

impl<A: Debug> Debug for core::option::IntoIter<A>

Source

impl<A: Debug> Debug for OptionFlatten<A>

1.96.0 ยท Source

impl<A: Debug> Debug for RangeFromIter<A>

1.95.0 ยท Source

impl<A: Debug> Debug for RangeInclusiveIter<A>

1.96.0 ยท Source

impl<A: Debug> Debug for RangeIter<A>

1.0.0 ยท Source

impl<A: Debug> Debug for core::iter::Repeat<A>

1.82.0 ยท Source

impl<A: Debug> Debug for RepeatN<A>

1.55.0 ยท Source

impl<B: Debug, C: Debug> Debug for ControlFlow<B, C>

Source

impl<Dyn: PointeeSized> Debug for DynMetadata<Dyn>

1.4.0 ยท Source

impl<F: FnPtr> Debug for F

Source

impl<F> Debug for CharPredicateSearcher<'_, F>
where F: FnMut(char) -> bool,

1.34.0 ยท Source

impl<F> Debug for core::iter::FromFn<F>

1.93.0 ยท Source

impl<F> Debug for core::fmt::FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result,

1.68.0 ยท Source

impl<F> Debug for OnceWith<F>

1.64.0 ยท Source

impl<F> Debug for PollFn<F>

1.68.0 ยท Source

impl<F> Debug for RepeatWith<F>

Source

impl<G> Debug for FromCoroutine<G>

1.9.0 ยท Source

impl<H> Debug for BuildHasherDefault<H>

Source

impl<I, G> Debug for IntersperseWith<I, G>
where I: Iterator + Debug, I::Item: Debug, G: Debug,

1.29.0 ยท Source

impl<I, U> Debug for Flatten<I>
where I: Debug + Iterator<Item: IntoIterator<IntoIter = U, Item = U::Item>>, U: Debug + Iterator,

Source

impl<I: Debug + Iterator, const N: usize> Debug for ArrayChunks<I, N>
where I::Item: Debug,

Source

impl<I: Debug + Iterator> Debug for Intersperse<I>
where I::Item: Clone + Debug,

1.0.0 ยท Source

impl<I: Debug + Iterator> Debug for Peekable<I>
where I::Item: Debug,

1.9.0 ยท Source

impl<I: Debug, F> Debug for FilterMap<I, F>

1.9.0 ยท Source

impl<I: Debug, F> Debug for Inspect<I, F>

1.9.0 ยท Source

impl<I: Debug, F> Debug for Map<I, F>

1.9.0 ยท Source

impl<I: Debug, P> Debug for Filter<I, P>

1.57.0 ยท Source

impl<I: Debug, P> Debug for MapWhile<I, P>

1.9.0 ยท Source

impl<I: Debug, P> Debug for SkipWhile<I, P>

1.9.0 ยท Source

impl<I: Debug, P> Debug for TakeWhile<I, P>

1.9.0 ยท Source

impl<I: Debug, St: Debug, F> Debug for Scan<I, St, F>

1.9.0 ยท Source

impl<I: Debug, U, F> Debug for FlatMap<I, U, F>
where U: IntoIterator<IntoIter: Debug>,

1.1.0 ยท Source

impl<I: Debug> Debug for Cloned<I>

1.36.0 ยท Source

impl<I: Debug> Debug for Copied<I>

1.0.0 ยท Source

impl<I: Debug> Debug for Cycle<I>

1.0.0 ยท Source

impl<I: Debug> Debug for Enumerate<I>

Source

impl<I: Debug> Debug for FromIter<I>

1.0.0 ยท Source

impl<I: Debug> Debug for Fuse<I>

1.0.0 ยท Source

impl<I: Debug> Debug for Skip<I>

1.28.0 ยท Source

impl<I: Debug> Debug for StepBy<I>

1.0.0 ยท Source

impl<I: Debug> Debug for core::iter::Take<I>

Source

impl<I: Iterator + Debug, F, const N: usize> Debug for MapWindows<I, F, N>

1.9.0 ยท Source

impl<I> Debug for DecodeUtf16<I>
where I: Iterator<Item = u16> + Debug,

Source

impl<Idx: Debug> Debug for Clamp<Idx>

1.0.0 ยท Source

impl<Idx: Debug> Debug for core::ops::Range<Idx>

1.96.0 ยท Source

impl<Idx: Debug> Debug for core::range::Range<Idx>

1.0.0 ยท Source

impl<Idx: Debug> Debug for core::ops::RangeFrom<Idx>

1.96.0 ยท Source

impl<Idx: Debug> Debug for core::range::RangeFrom<Idx>

1.26.0 ยท Source

impl<Idx: Debug> Debug for core::ops::RangeInclusive<Idx>

1.95.0 ยท Source

impl<Idx: Debug> Debug for core::range::RangeInclusive<Idx>

1.0.0 ยท Source

impl<Idx: Debug> Debug for RangeTo<Idx>

1.26.0 ยท Source

impl<Idx: Debug> Debug for core::ops::RangeToInclusive<Idx>

1.96.0 ยท Source

impl<Idx: Debug> Debug for core::range::RangeToInclusive<Idx>

Source

impl<P: Debug + ?Sized> Debug for MaybeDangling<P>

1.33.0 ยท Source

impl<Ptr: Debug> Debug for Pin<Ptr>

Source

impl<T, F> Debug for DropGuard<T, F>
where T: Debug, F: FnOnce(T),

Source

impl<T, const N: usize> Debug for Mask<T, N>
where T: MaskElement + Debug,

Source

impl<T, const N: usize> Debug for Simd<T, N>
where T: SimdElement + Debug,

1.0.0 ยท Source

impl<T: ?Sized + Debug> Debug for Ref<'_, T>

1.0.0 ยท Source

impl<T: ?Sized + Debug> Debug for RefCell<T>

1.0.0 ยท Source

impl<T: ?Sized + Debug> Debug for RefMut<'_, T>

Source

impl<T: ?Sized, const VARIANT: u32, const FIELD: u32> Debug for FieldRepresentingType<T, VARIANT, FIELD>

1.0.0 ยท Source

impl<T: ?Sized> Debug for PhantomData<T>

Source

impl<T: ?Sized> Debug for SyncUnsafeCell<T>

Source

impl<T: ?Sized> Debug for SyncView<T>

1.9.0 ยท Source

impl<T: ?Sized> Debug for UnsafeCell<T>

Source

impl<T: ?Sized> Debug for UnsafePinned<T>

1.0.0 ยท Source

impl<T: Copy + Debug> Debug for Cell<T>

1.20.0 ยท Source

impl<T: Debug + ?Sized> Debug for ManuallyDrop<T>

Source

impl<T: Debug + PointeeSized> Debug for TraitImpl<T>

1.0.0 ยท Source

impl<T: Debug, E: Debug> Debug for Result<T, E>

1.80.0 ยท Source

impl<T: Debug, F> Debug for LazyCell<T, F>

1.34.0 ยท Source

impl<T: Debug, F> Debug for Successors<T, F>

1.27.0 ยท Source

impl<T: Debug, P> Debug for core::slice::RSplit<'_, T, P>
where P: FnMut(&T) -> bool,

1.27.0 ยท Source

impl<T: Debug, P> Debug for RSplitMut<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for core::slice::RSplitN<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for RSplitNMut<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for core::slice::Split<'_, T, P>
where P: FnMut(&T) -> bool,

1.51.0 ยท Source

impl<T: Debug, P> Debug for core::slice::SplitInclusive<'_, T, P>
where P: FnMut(&T) -> bool,

1.51.0 ยท Source

impl<T: Debug, P> Debug for SplitInclusiveMut<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for SplitMut<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for core::slice::SplitN<'_, T, P>
where P: FnMut(&T) -> bool,

1.9.0 ยท Source

impl<T: Debug, P> Debug for SplitNMut<'_, T, P>
where P: FnMut(&T) -> bool,

1.0.0 ยท Source

impl<T: Debug, U: Debug> Debug for core::io::Chain<T, U>

1.40.0 ยท Source

impl<T: Debug, const N: usize> Debug for core::array::IntoIter<T, N>

1.0.0 ยท Source

impl<T: Debug, const N: usize> Debug for [T; N]

1.0.0 ยท Source

impl<T: Debug> Debug for (Tโ‚, Tโ‚‚, โ€ฆ, Tโ‚™)

This trait is implemented for tuples up to twelve items long.

1.16.0 ยท Source

impl<T: Debug> Debug for AssertUnwindSafe<T>

1.17.0 ยท Source

impl<T: Debug> Debug for Bound<T>

1.0.0 ยท Source

impl<T: Debug> Debug for Cursor<T>

1.0.0 ยท Source

impl<T: Debug> Debug for core::result::IntoIter<T>

1.9.0 ยท Source

impl<T: Debug> Debug for core::slice::Iter<'_, T>

1.9.0 ยท Source

impl<T: Debug> Debug for core::slice::IterMut<'_, T>

1.2.0 ยท Source

impl<T: Debug> Debug for Once<T>

1.70.0 ยท Source

impl<T: Debug> Debug for OnceCell<T>

1.0.0 ยท Source

impl<T: Debug> Debug for Option<T>

1.36.0 ยท Source

impl<T: Debug> Debug for Poll<T>

1.48.0 ยท Source

impl<T: Debug> Debug for Ready<T>

1.0.0 ยท Source

impl<T: Debug> Debug for Rev<T>

1.19.0 ยท Source

impl<T: Debug> Debug for Reverse<T>

1.74.0 ยท Source

impl<T: Debug> Debug for Saturating<T>

1.0.0 ยท Source

impl<T: Debug> Debug for core::io::Take<T>

1.0.0 ยท Source

impl<T: Debug> Debug for Wrapping<T>

Source

impl<T: Debug> Debug for Yeet<T>

1.0.0 ยท Source

impl<T: Debug> Debug for [T]

1.98.0 ยท Source

impl<T: NumBufferTrait> Debug for NumBuffer<T>

1.0.0 ยท Source

impl<T: PointeeSized + Debug> Debug for &T

1.0.0 ยท Source

impl<T: PointeeSized + Debug> Debug for &mut T

1.0.0 ยท Source

impl<T: PointeeSized> Debug for *const T

1.0.0 ยท Source

impl<T: PointeeSized> Debug for *mut T

1.25.0 ยท Source

impl<T: PointeeSized> Debug for NonNull<T>

1.3.0 ยท Source

impl<T> Debug for AtomicPtr<T>

Source

impl<T> Debug for BorrowedBuf<'_, T>

Source

impl<T> Debug for BorrowedCursor<'_, T>

1.21.0 ยท Source

impl<T> Debug for Discriminant<T>

1.9.0 ยท Source

impl<T> Debug for core::iter::Empty<T>

1.41.0 ยท Source

impl<T> Debug for MaybeUninit<T>

1.28.0 ยท Source

impl<T> Debug for NonZero<T>

1.48.0 ยท Source

impl<T> Debug for Pending<T>

Source

impl<T> Debug for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Debug for PhantomInvariant<T>
where T: ?Sized,

Source

impl<Y: Debug, R: Debug> Debug for CoroutineState<Y, R>